=======
History
=======

0.3.1 (2022-03-03)
------------------

* First release on PyPI.

0.4.0 (2022-03-27)
------------------

* Change to mantain order, comments and support exclamation marks in Cloudformation
